Struct amazon_sp_vendor_shipments::models::carton_reference_details::CartonReferenceDetails
source · [−]pub struct CartonReferenceDetails {
pub carton_count: Option<i32>,
pub carton_reference_numbers: Vec<String>,
}Fields
carton_count: Option<i32>Pallet level carton count is mandatory for single item pallet and optional for mixed item pallet.
carton_reference_numbers: Vec<String>Array of reference numbers for the carton that are part of this pallet/shipment. Please provide the cartonSequenceNumber from the ‘cartons’ segment to refer to that carton’s details here.
Implementations
sourceimpl CartonReferenceDetails
impl CartonReferenceDetails
pub fn new(carton_reference_numbers: Vec<String>) -> CartonReferenceDetails